@@ -2,11 +2,7 @@
 from __future__ import absolute_import, division, print_function, unicode_literals
 import pytest
 import astropy.units as u
-from ....utils.testing import (
-    assert_quantity_allclose,
-    requires_data,
-    requires_dependency,
-)
+from ....utils.testing import assert_quantity_allclose, requires_data
 from ....maps import WcsGeom
 from .. import JFactory, profiles, PrimaryFlux, compute_dm_flux
 
@@ -27,7 +23,6 @@ def prim_flux():
     return PrimaryFlux(mDM=1 * u.TeV, channel="W")
 
 
-@requires_dependency("scipy")
 @requires_data("gammapy-extra")
 def test_dmfluxmapmaker(jfact, prim_flux):
     x_section = 1e-26 * u.Unit("cm3 s-1")
@@ -37,5 +32,5 @@ def test_dmfluxmapmaker(jfact, prim_flux):
     )
 
     actual = flux[5, 5]
-    desired = 6.503327e-13 / u.cm ** 2 / u.s
+    desired = 6.49463e-13 / u.cm ** 2 / u.s
     assert_quantity_allclose(actual, desired, rtol=1e-5)
